// The tests in this file and the test_100 folder are for
// lessons and exercises in the online book "100 exercises with qsv".

// You may read lessons and try out the exercises at:
// https://100.dathere.com

// Warning: These tests may contain solutions to the exercises.

mod lesson_0;
mod lesson_1;
mod lesson_2;
mod lesson_3;
#[cfg(feature = "polars")]
mod lesson_4;
